'use client'

import { useEffect, useState } from 'react'
import { FiClock, FiGrid, FiCheck, FiTrash2 } from 'react-icons/fi'
import DashboardLayout from '@/components/layout/DashboardLayout'
import { useUser } from '@/contexts/UserContext'
import { qrOrderService } from '@/services/api'
import { getDate } from '@/config/tableConfig'
import { useNotificationStore } from '@/store/useNotificationStore'

interface QROrder {
    id: number
    table: {
        name: string
    }
    status: string
    created_at: string
    items: {
        id: number
        product: {
            id: number
            name: string
            price: string
        }
        quantity: number
        price: string
    }[]
    total_price: number
}

export default function QROrdersPage() {
    const { user } = useUser()
    const [orders, setOrders] = useState<QROrder[]>([])
    const [loading, setLoading] = useState(true)
    const [previousOrderCount, setPreviousOrderCount] = useState(0)

    // s

    const fetchQROrders = async () => {
        try {
            const response = await qrOrderService.index(user?.token || '')
            const newOrders = response.data.orders
            
            if (previousOrderCount < newOrders.length) {
                const newOrderCount = newOrders.length - previousOrderCount
                
            }
            
            setOrders(newOrders)
            setPreviousOrderCount(newOrders.length)
            setLoading(false)
        } catch (error) {
            console.error('QR siparişleri yüklenirken hata:', error)
            setLoading(false)
        }
    }

    const handleConfirmOrder = async (orderId: number) => {
        try {
            await qrOrderService.approve(orderId.toString(), user?.token || '')
            // Siparişleri yenile
            fetchQROrders()
        } catch (error) {
            console.error('Sipariş onaylanırken hata:', error)
        }
    }

    const handleDeleteOrder = async (orderId: number) => {
        if (window.confirm('Bu siparişi silmek istediğinize emin misiniz?')) {
            try {
                await qrOrderService.reject(orderId.toString(), user?.token || '')
                // Siparişleri yenile
                fetchQROrders()
            } catch (error) {
                console.error('Sipariş silinirken hata:', error)
            }
        }
    }

    useEffect(() => {
        if (user?.token) {
            fetchQROrders()
            // Her 10 saniyede bir yenile (daha sık kontrol)
            const interval = setInterval(fetchQROrders, 10000)
            return () => clearInterval(interval)
        }
    }, [user?.token])

    return (
        <DashboardLayout>
            <div className="space-y-6">
                {/* Başlık */}
                <div>
                    <h1 className="text-2xl font-bold text-slate-800 dark:text-white">
                        QR Siparişleri
                    </h1>
                    <p className="mt-1 text-sm text-slate-500 dark:text-slate-400">
                        Bekleyen QR siparişlerini görüntüleyin
                    </p>
                </div>

                {/* Sipariş Kartları */}
                <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-6">
                    {orders?.map((order) => (
                        <div
                            key={order?.id}
                            className="bg-white/50 dark:bg-slate-800/50 backdrop-blur-sm 
                       border border-slate-200/50 dark:border-slate-700/50 
                       rounded-2xl shadow-lg"
                        >
                            {/* Üst Bilgi */}
                            <div className="p-6 border-b border-slate-200/50 dark:border-slate-700/50">
                                <div className="flex items-center justify-between">
                                    <div className="flex items-center gap-3">
                                        <div className="p-2 bg-fuchsia-50 dark:bg-fuchsia-900/50 rounded-xl">
                                            <FiGrid className="w-5 h-5 text-fuchsia-500" />
                                        </div>
                                        <div>
                                            <h3 className="font-semibold text-slate-800 dark:text-white">
                                                {order.table?.name}
                                            </h3>
                                            <div className="flex items-center gap-2 mt-1">
                                                <FiClock className="w-4 h-4 text-slate-400" />
                                                <span className="text-sm text-slate-500 dark:text-slate-400">
                                                    {getDate(order?.created_at)}
                                                </span>
                                            </div>
                                        </div>
                                    </div>
                                    <span className={`px-3 py-1 text-xs font-medium rounded-full 
                                bg-amber-100 dark:bg-amber-900/50 
                                text-amber-600 dark:text-amber-400`}>
                                        {order?.status === 'pending' ? 'Bekliyor' : 'Tamamlandı'}
                                    </span>
                                </div>
                            </div>

                            {/* Ürün Listesi */}
                            <div className="p-6 space-y-4">
                                {order.items && order.items.map((item) => (
                                    <div
                                        key={item.id}
                                        className="flex items-center justify-between p-3 rounded-xl
                             bg-slate-50/50 dark:bg-slate-700/50"
                                    >
                                        <div>
                                            <h4 className="font-medium text-slate-800 dark:text-white">
                                                {item?.product?.name}
                                            </h4>
                                            <div className="flex items-center gap-2 mt-1">
                                                <span className="text-xs px-2 py-0.5 rounded-full 
                                     bg-fuchsia-100/50 dark:bg-fuchsia-900/50 
                                     text-fuchsia-600 dark:text-fuchsia-400">
                                                    {item?.quantity} adet
                                                </span>
                                                <span className="text-sm text-slate-500 dark:text-slate-400">
                                                    ₺{Number(item?.price) * item?.quantity}
                                                </span>
                                            </div>
                                        </div>
                                    </div>
                                ))}

                                {/* Toplam Tutar */}
                                <div className="pt-4 border-t border-slate-200/50 dark:border-slate-700/50">
                                    <div className="flex items-center justify-between">
                                        <span className="text-sm font-medium text-slate-600 dark:text-slate-300">
                                            Toplam Tutar
                                        </span>
                                        <span className="text-lg font-semibold text-slate-800 dark:text-white">
                                            ₺{order.total_price || 0}
                                        </span>
                                    </div>
                                </div>

                                {/* Aksiyon Butonları */}
                                <div className="flex gap-2 pt-4 border-t border-slate-200/50 dark:border-slate-700/50">
                                    <button
                                        onClick={() => handleConfirmOrder(order.id)}
                                        disabled={order.status !== 'pending'}
                                        className={`flex-1 px-4 py-2 text-sm font-medium rounded-xl
                                                 flex items-center justify-center gap-2 transition-all
                                                 ${order.status === 'pending'
                                                ? 'bg-green-500 hover:bg-green-600 text-white'
                                                : 'bg-slate-100 dark:bg-slate-700 text-slate-400 dark:text-slate-500 cursor-not-allowed'
                                            }`}
                                    >
                                        <FiCheck className="w-6 h-6" />
                                        {order.status === 'pending' ? 'Onayla' : 'Onaylandı'}
                                    </button>

                                    <button
                                        onClick={() => handleDeleteOrder(order.id)}
                                        className="px-4 py-2 text-sm font-medium text-red-500 hover:text-white
                                                 bg-red-50 hover:bg-red-500 dark:bg-red-900/10 
                                                 dark:hover:bg-red-500 rounded-xl transition-all
                                                 flex items-center justify-center gap-2"
                                    >
                                        <FiTrash2 className="w-4 h-4" />
                                        Sil
                                    </button>
                                </div>
                            </div>
                        </div>
                    ))}
                </div>

                {/* Yükleniyor */}
                {loading && (
                    <div className="flex justify-center items-center min-h-[400px]">
                        <div className="animate-spin rounded-full h-12 w-12 border-b-2 border-fuchsia-500"></div>
                    </div>
                )}

                {/* Veri Yoksa */}
                {!loading && orders.length === 0 && (
                    <div className="flex flex-col items-center justify-center min-h-[400px] 
                       bg-white/50 dark:bg-slate-800/50 backdrop-blur-sm 
                       rounded-2xl border border-slate-200/50 dark:border-slate-700/50 
                       p-8">
                        <FiCheck className="w-16 h-16 text-green-500 mb-4" />
                        <h2 className="text-xl font-semibold text-slate-800 dark:text-white mb-2">
                            Bekleyen Sipariş Yok
                        </h2>
                        <p className="text-slate-500 dark:text-slate-400 text-center">
                            Şu anda bekleyen QR siparişi bulunmuyor.
                        </p>
                    </div>
                )}
            </div>
        </DashboardLayout>
    )
} 